@@ -23,7 +23,7 @@ package Math::Subsets::List;
 
 use strict;
 
-sub subsets(&@)
+sub subsets(&@)        # Generate all the subsets of a list  
  {my $s = shift;       # Subroutine to call to process each subset
 
   my $n = scalar(@_);  # Size of list to be subsetted
@@ -46,6 +46,7 @@ sub subsets(&@)
    };
 
   &$p;
+  $p = undef;          # Break memory loop per Philipp Rumpf    
   
   2**$n;
  }
@@ -59,8 +60,7 @@ use vars qw(@ISA @EXPORT $VERSION);
 
 @ISA     = qw(Exporter);
 @EXPORT  = qw(subsets);
-#           1.004   # Saturday 21 March  2009
-$VERSION = '1.006'; # Mondday  27 August 2012
+$VERSION = '1.007'; # Monday 26 Jan 2015
 
 =head1 Description
 
@@ -98,14 +98,19 @@ the "./" notation, you can do this:
 
 =head1 Author
 
-PhilipRBrenan@gmail.com
+PhilipRBrenan@appaapps.com
+
+http://www.appaapps.com
+
+=head1 Acknowledgments
+
+With lots of help and advice from Philip Rumpff to who I am most grateful.
 
 =head1 See Also
 
-
 =over
 
-=item L<Math::Cartesian::List>
+=item L<Math::Cartesian::Product>
 
 =item L<Math::Disarrange::List>
 
